.. highlight:: shell

============
Installation
============
Currently the installation of `hvl_ccb` is only possible using the sources from GitLab.

..
    Stable release
    --------------

    To install HVL Common Code Base, run this command in your terminal:

    .. code-block:: console

        $ pip install hvl_ccb

    This is the preferred method to install HVL Common Code Base, as it will always install the most recent stable release.

    If you don't have `pip`_ installed, this `Python installation guide`_ can guide
    you through the process.

    .. _pip: https://pip.pypa.io
    .. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for HVL Common Code Base can be downloaded from the `GitLab repo`_.

You can either clone the repository:

.. code-block:: console

    $ git clone git@gitlab.ethz.ch:hvl_priv/hvl_ccb.git

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://gitlab.ethz.ch/hvl_priv/hvl_ccb/-/archive/master/hvl_ccb.tar.gz

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _GitLab repo: https://gitlab.ethz.ch/hvl_priv/hvl_ccb
.. _tarball: https://gitlab.ethz.ch/hvl_priv/hvl_ccb/-/archive/master/hvl_ccb.tar.gz
